@@ -29,20 +29,33 @@ class PortAPITestCase(base.PolicyBaseTestCase):
 
         self.network = {
             'id': uuidutils.generate_uuid(),
+            'tenant_id': self.project_id,
             'project_id': self.project_id}
-        self.target = {
-            'project_id': self.project_id,
+        self.alt_network = {
+            'id': uuidutils.generate_uuid(),
             'tenant_id': self.alt_project_id,
+            'project_id': self.alt_project_id}
+        self.target = {
+            'tenant_id': self.project_id,
+            'project_id': self.project_id,
             'network_id': self.network['id'],
             'ext_parent_network_id': self.network['id']}
         self.alt_target = {
+            'tenant_id': self.project_id,
             'project_id': self.alt_project_id,
-            'tenant_id': self.alt_project_id,
-            'network_id': self.network['id'],
-            'ext_parent_network_id': self.network['id']}
+            'network_id': self.alt_network['id'],
+            'ext_parent_network_id': self.alt_network['id']}
+
+        networks = {
+            self.network['id']: self.network,
+            self.alt_network['id']: self.alt_network,
+        }
+
+        def get_network(context, id, fields=None):
+            return networks[id]
 
         self.plugin_mock = mock.Mock()
-        self.plugin_mock.get_network.return_value = self.network
+        self.plugin_mock.get_network.side_effect = get_network
         mock.patch(
             'neutron_lib.plugins.directory.get_plugin',
             return_value=self.plugin_mock).start()
@@ -496,12 +509,14 @@ class AdminTests(PortAPITestCase):
                            'create_port:binding:host_id', self.alt_target))
 
     def test_create_port_with_binding_profile(self):
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'create_port:binding:profile', self.target))
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'create_port:binding:profile', self.alt_target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:binding:profile',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:binding:profile',
+            self.alt_target)
 
     def test_create_port_with_binding_vnic_type(self):
         self.assertTrue(
@@ -679,12 +694,14 @@ class AdminTests(PortAPITestCase):
                            'update_port:binding:host_id', self.alt_target))
 
     def test_update_port_with_binding_profile(self):
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'update_port:binding:profile', self.target))
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'update_port:binding:profile', self.alt_target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:binding:profile',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:binding:profile',
+            self.alt_target)
 
     def test_update_port_with_binding_vnic_type(self):
         self.assertTrue(
@@ -768,60 +785,52 @@ class ProjectMemberTests(AdminTests):
         target['device_owner'] = 'network:test'
         alt_target = self.alt_target.copy()
         alt_target['device_owner'] = 'network:test'
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:device_owner',
-            target)
+        self.assertTrue(
+            policy.enforce(self.context, 'create_port:device_owner', target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:device_owner',
             alt_target)
 
     def test_create_port_with_mac_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:mac_address',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'create_port:mac_address',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:mac_address',
             self.alt_target)
 
     def test_create_port_with_fixed_ips(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:fixed_ips',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'create_port:fixed_ips', self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:fixed_ips',
             self.alt_target)
 
     def test_create_port_with_fixed_ips_and_ip_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:fixed_ips:ip_address',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'create_port:fixed_ips:ip_address',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:fixed_ips:ip_address',
             self.alt_target)
 
     def test_create_port_with_fixed_ips_and_subnet_id(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:fixed_ips:subnet_id',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'create_port:fixed_ips:subnet_id',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:fixed_ips:subnet_id',
             self.alt_target)
 
     def test_create_port_with_port_security_enabled(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:port_security_enabled',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'create_port:port_security_enabled',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:port_security_enabled',
@@ -857,11 +866,9 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_create_port_with_allowed_address_pairs(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_port:allowed_address_pairs',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'create_port:allowed_address_pairs',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -869,11 +876,10 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_create_port_with_allowed_address_pairs_and_mac_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_port:allowed_address_pairs:mac_address',
-            self.target)
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_port:allowed_address_pairs:mac_address',
+                self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -881,11 +887,10 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_create_port_with_allowed_address_pairs_and_ip_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_port:allowed_address_pairs:ip_address',
-            self.target)
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_port:allowed_address_pairs:ip_address',
+                self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -990,10 +995,8 @@ class ProjectMemberTests(AdminTests):
         target['device_owner'] = 'network:test'
         alt_target = self.alt_target.copy()
         alt_target['device_owner'] = 'network:test'
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:device_owner',
-            target)
+        self.assertTrue(
+            policy.enforce(self.context, 'update_port:device_owner', target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'update_port:device_owner',
@@ -1010,40 +1013,36 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_update_port_with_fixed_ips(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:fixed_ips',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'update_port:fixed_ips',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'update_port:fixed_ips',
             self.alt_target)
 
     def test_update_port_with_fixed_ips_and_ip_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:fixed_ips:ip_address',
-            self.target)
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_port:fixed_ips:ip_address', self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'update_port:fixed_ips:ip_address',
             self.alt_target)
 
     def test_update_port_with_fixed_ips_and_subnet_id(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:fixed_ips:subnet_id',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'update_port:fixed_ips:subnet_id',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'update_port:fixed_ips:subnet_id',
             self.alt_target)
 
     def test_update_port_with_port_security_enabled(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:port_security_enabled',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'update_port:port_security_enabled',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'update_port:port_security_enabled',
@@ -1079,11 +1078,9 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_update_port_with_allowed_address_pairs(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_port:allowed_address_pairs',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context, 'update_port:allowed_address_pairs',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -1091,11 +1088,11 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_update_port_with_allowed_address_pairs_and_mac_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_port:allowed_address_pairs:mac_address',
-            self.target)
+        self.assertTrue(
+                policy.enforce(
+                    self.context,
+                    'update_port:allowed_address_pairs:mac_address',
+                    self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -1103,11 +1100,11 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_update_port_with_allowed_address_pairs_and_ip_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_port:allowed_address_pairs:ip_address',
-            self.target)
+        self.assertTrue(
+                policy.enforce(
+                    self.context,
+                    'update_port:allowed_address_pairs:ip_address',
+                    self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -1158,10 +1155,78 @@ class ProjectReaderTests(ProjectMemberTests):
     def test_create_port(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port', self.target)
+            policy.enforce,
+            self.context, 'update_port:fixed_ips',
+            self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port', self.alt_target)
+            policy.enforce,
+            self.context, 'update_port:fixed_ips',
+            self.alt_target)
+
+    def test_create_port_with_device_owner(self):
+        target = self.target.copy()
+        target['device_owner'] = 'network:test'
+        alt_target = self.alt_target.copy()
+        alt_target['device_owner'] = 'network:test'
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:device_owner',
+            target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:device_owner',
+            alt_target)
+
+    def test_create_port_with_mac_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:mac_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:mac_address',
+            self.alt_target)
+
+    def test_create_port_with_fixed_ips(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips',
+            self.alt_target)
+
+    def test_create_port_with_fixed_ips_and_ip_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips:ip_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips:ip_address',
+            self.alt_target)
+
+    def test_create_port_with_fixed_ips_and_subnet_id(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips:subnet_id',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips:subnet_id',
+            self.alt_target)
+
+    def test_create_port_with_port_security_enabled(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:port_security_enabled',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:port_security_enabled',
+            self.alt_target)
 
     def test_create_port_with_binding_vnic_type(self):
         self.assertRaises(
@@ -1173,13 +1238,107 @@ class ProjectReaderTests(ProjectMemberTests):
             policy.enforce, self.context, 'create_port:binding:vnic_type',
             self.alt_target)
 
+    def test_create_port_with_allowed_address_pairs(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs',
+            self.alt_target)
+
+    def test_create_port_with_allowed_address_pairs_and_mac_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:mac_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:mac_address',
+            self.alt_target)
+
+    def test_create_port_with_allowed_address_pairs_and_ip_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:ip_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:ip_address',
+            self.alt_target)
+
     def test_update_port(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port', self.target)
+            policy.enforce,
+            self.context, 'update_port:fixed_ips:subnet_id',
+            self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port', self.alt_target)
+            policy.enforce,
+            self.context, 'update_port:fixed_ips:subnet_id',
+            self.alt_target)
+
+    def test_update_port_with_device_owner(self):
+        target = self.target.copy()
+        target['device_owner'] = 'network:test'
+        alt_target = self.alt_target.copy()
+        alt_target['device_owner'] = 'network:test'
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:device_owner',
+            target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:device_owner',
+            alt_target)
+
+    def test_update_port_with_fixed_ips(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:fixed_ips',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:fixed_ips',
+            self.alt_target)
+
+    def test_update_port_with_fixed_ips_and_ip_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:fixed_ips:ip_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:fixed_ips:ip_address',
+            self.alt_target)
+
+    def test_update_port_with_fixed_ips_and_subnet_id(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:fixed_ips:subnet_id',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:fixed_ips:subnet_id',
+            self.alt_target)
+
+    def test_update_port_with_port_security_enabled(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:port_security_enabled',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:port_security_enabled',
+            self.alt_target)
 
     def test_update_port_with_binding_vnic_type(self):
         self.assertRaises(
@@ -1191,6 +1350,42 @@ class ProjectReaderTests(ProjectMemberTests):
             policy.enforce, self.context, 'update_port:binding:vnic_type',
             self.alt_target)
 
+    def test_update_port_with_allowed_address_pairs(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs',
+            self.alt_target)
+
+    def test_update_port_with_allowed_address_pairs_and_mac_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs:mac_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs:mac_address',
+            self.alt_target)
+
+    def test_update_port_with_allowed_address_pairs_and_ip_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs:ip_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs:ip_address',
+            self.alt_target)
+
     def test_update_ports_tags(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
@@ -1206,3 +1401,192 @@ class ProjectReaderTests(ProjectMemberTests):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'delete_port', self.alt_target)
+
+
+class ServiceRoleTests(PortAPITestCase):
+
+    def setUp(self):
+        super(ServiceRoleTests, self).setUp()
+        self.context = self.service_ctx
+
+    def test_create_port(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_port', self.target))
+
+    def test_create_port_with_device_owner(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_port:device_owner', self.target))
+
+    def test_create_port_with_mac_address(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_port:mac_address', self.target))
+
+    def test_create_port_with_fixed_ips(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_port:fixed_ips', self.target))
+
+    def test_create_port_with_fixed_ips_and_ip_address(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_port:fixed_ips:ip_address', self.target))
+
+    def test_create_port_with_fixed_ips_and_subnet_id(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_port:fixed_ips:subnet_id', self.target))
+
+    def test_create_port_with_port_security_enabled(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'create_port:port_security_enabled',
+                self.target))
+
+    def test_create_port_with_binding_host_id(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:binding:host_id', self.target))
+
+    def test_create_port_with_binding_profile(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:binding:profile', self.target))
+
+    def test_create_port_with_binding_vnic_type(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:binding:vnic_type', self.target))
+
+    def test_create_port_with_allowed_address_pairs(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs',
+            self.target)
+
+    def test_create_port_with_allowed_address_pairs_and_mac_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:mac_address',
+            self.alt_target)
+
+    def test_create_port_with_allowed_address_pairs_and_ip_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:ip_address',
+            self.target)
+
+    def test_get_port(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'get_port', self.target))
+
+    def test_get_port_binding_vif_type(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'get_port:binding:vif_type', self.target))
+
+    def test_get_port_binding_vif_details(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'get_port:binding:vif_details', self.target))
+
+    def test_get_port_binding_host_id(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'get_port:binding:host_id', self.target))
+
+    def test_get_port_binding_profile(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'get_port:binding:profile', self.target))
+
+    def test_get_port_resource_request(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'get_port:resource_request',
+            self.target)
+
+    def test_update_port(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'update_port', self.target))
+
+    def test_update_port_with_device_owner(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_port:device_owner', self.target))
+
+    def test_update_port_with_mac_address(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_port:mac_address', self.target))
+
+    def test_update_port_with_fixed_ips(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_port:fixed_ips', self.target))
+
+    def test_update_port_with_fixed_ips_and_ip_address(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_port:fixed_ips:ip_address', self.target))
+
+    def test_update_port_with_fixed_ips_and_subnet_id(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_port:fixed_ips:subnet_id', self.target))
+
+    def test_update_port_with_port_security_enabled(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_port:port_security_enabled',
+                self.target))
+
+    def test_update_port_with_binding_host_id(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:binding:host_id', self.target))
+
+    def test_update_port_with_binding_profile(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:binding:profile', self.target))
+
+    def test_update_port_with_binding_vnic_type(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_port:binding:vnic_type', self.target))
+
+    def test_update_port_with_allowed_address_pairs(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs',
+            self.target)
+
+    def test_update_port_with_allowed_address_pairs_and_mac_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs:mac_address',
+            self.target)
+
+    def test_update_port_with_allowed_address_pairs_and_ip_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs:ip_address',
+            self.target)
+
+    def test_update_port_data_plane_status(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:data_plane_status', self.target)
+
+    def test_delete_port(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'delete_port', self.target))
